| MBESS | R Documentation |
MBESS Implements methods that are useful in designing research studies and analyzing data, with
particular emphasis on methods that are developed for or used within the behavioral,
educational, and social sciences (broadly defined). That being said, many of the methods
implemented within MBESS are applicable to a wide variety of disciplines. MBESS has a
suite of functions for a variety of related topics, such as effect sizes, confidence intervals
for effect sizes (including standardized effect sizes and noncentral effect sizes), sample size
planning (from the accuracy in parameter estimation [AIPE], power analytic, equivalence, and
minimum-risk point estimation perspectives), mediation analysis, various properties of
distributions, and a variety of utility functions. MBESS (pronounced 'em-bes') was originally
an acronym for 'Methods for the Behavioral, Educational, and Social Sciences,' but MBESS became
more general and now contains methods applicable and used in a wide variety of fields and is an
orphan acronym, in the sense that what was an acronym is now literally its name. MBESS has
greatly benefited from the contributions of many people. See the CONTRIBUTORS file
in the installed package for a detailed list of contributors and their contributions.
| Package: | MBESS |
| Type: | Package |
| Version: | 5.0.1 |
| Date: | 2026-06-03 |
| License: | GPL-2 | GPL-3 |
Please read the help files for information on the capabilities of the MBESS package. Feel free
to contact me if there is a feature you would like to see added if it would
complement the goals of the MBESS package. Beginning with version
4.8.0, the package also has a home on GitHub https://github.com/yelleKneK/MBESS.
Over the years, multiple people have contributed functions to the package. See individual
functions for details. MBESS is mature, stable, and widely used, and it remains fully supported. Maintenance mode does not mean the package is finished or abandoned: MBESS will continue to be maintained so that it keeps working with current versions of R and its dependencies, and it will remain on CRAN. New methodological development now takes place in its successor package, DMAR (Design, Measurement, and Analysis in R), which is available on CRAN. DMAR is where new methods will appear, and MBESS and DMAR are designed to coexist, so existing code that relies on MBESS will continue to work and there is no need to migrate.
Ken Kelley <kkelley@nd.edu; https://kenkelley.org/>
Maintainer: Ken Kelley <kkelley@nd.edu; https://kenkelley.org/>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.